@@ -86,7 +86,7 @@
 #define KFILEMETADATA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KFILEMETADATA_NO_DEPRECATED
-#  define KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55a00
+#  define KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KFILEMETADATA_NO_DEPRECATED_WARNINGS
 #  define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0x55a00
+#    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
@@ -139,6 +139,12 @@
 #else
 #  define KFILEMETADATA_DEPRECATED_VERSION_5_89(text)
 #endif
+
+#if KFILEMETADATA_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KFILEMETADATA_DEPRECATED_VERSION_5_91(text) KFILEMETADATA_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KFILEMETADATA_DEPRECATED_VERSION_5_91(text)
+#endif
 #define KFILEMETADATA_DEPRECATED_VERSION_5(minor, text)      KFILEMETADATA_DEPRECATED_VERSION_5_##minor(text)
 #define KFILEMETADATA_DEPRECATED_VERSION(major, minor, text) KFILEMETADATA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KFILEMETADATA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KFILEMETADATA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -204,7 +210,7 @@
 #define KFILEMETADATA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KFILEMETADATA_NO_DEPRECATED
-#  define KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55a00
+#  define KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
 #endif
 #ifdef KFILEMETADATA_NO_DEPRECATED_WARNINGS
 #  define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0
@@ -214,7 +220,7 @@
 #  ifdef KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE KFILEMETADATA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0x55a00
+#    define KFILEMETADATA_DEPRECATED_WARNINGS_SINCE 0x55e00
 #  endif
 #endif
 
@@ -257,6 +263,12 @@
 #else
 #  define KFILEMETADATA_DEPRECATED_VERSION_5_89(text)
 #endif
+
+#if KFILEMETADATA_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KFILEMETADATA_DEPRECATED_VERSION_5_91(text) KFILEMETADATA_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KFILEMETADATA_DEPRECATED_VERSION_5_91(text)
+#endif
 #define KFILEMETADATA_DEPRECATED_VERSION_5(minor, text)      KFILEMETADATA_DEPRECATED_VERSION_5_##minor(text)
 #define KFILEMETADATA_DEPRECATED_VERSION(major, minor, text) KFILEMETADATA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KFILEMETADATA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KFILEMETADATA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
